pub enum LoopVerbosity {
Silent,
LogEveryIteration,
LogActivityInterval {
every_n_seconds: u64,
},
}Expand description
Whether the loop should give additional messaging about its own working (this excludes messages about handling errors, and is just about reporting on normal working)
Variants
Silent
LogEveryIteration
LogActivityInterval
NOTE: the interval is at least as long; it is never shorter than the loop sleep time.